==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/PointSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
import { PointSeriesDescription } from "./PointSeriesDescription";
/**
 * @hidden
 */
var PointSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(PointSeriesDescriptionMetadata, _super);
    function PointSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PointSeriesDescriptionMetadata.b = function (a) {
        if (PointSeriesDescriptionMetadata.a == null) {
            PointSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PointSeriesDescriptionMetadata.c(PointSeriesDescriptionMetadata.a);
        }
        if (a.g(PointSeriesDescriptionMetadata.a)) {
            return;
        }
        a.s(PointSeriesDescriptionMetadata.a);
    };
    PointSeriesDescriptionMetadata.c = function (a) {
        HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
    };
    PointSeriesDescriptionMetadata.d = function (a) {
        PointSeriesDescriptionMetadata.b(a);
        a.u("PointSeries", function () { return new PointSeriesDescription(); });
        a.t("PointSeries", PointSeriesDescriptionMetadata.a);
    };
    PointSeriesDescriptionMetadata.$t = markType(PointSeriesDescriptionMetadata, 'PointSeriesDescriptionMetadata');
    PointSeriesDescriptionMetadata.a = null;
    return PointSeriesDescriptionMetadata;
}(Base));
export { PointSeriesDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/PointSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
import { PointSeriesDescription } from "./PointSeriesDescription";
/**
 * @hidden
 */
var PointSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(PointSeriesDescriptionMetadata, _super);
    function PointSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PointSeriesDescriptionMetadata.b = function (a) {
        if (PointSeriesDescriptionMetadata.a == null) {
            PointSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PointSeriesDescriptionMetadata.c(PointSeriesDescriptionMetadata.a);
        }
        if (a.j(PointSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(PointSeriesDescriptionMetadata.a);
    };
    PointSeriesDescriptionMetadata.c = function (a) {
        HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
    };
    PointSeriesDescriptionMetadata.d = function (a) {
        PointSeriesDescriptionMetadata.b(a);
        a.aa("PointSeries", function () { return new PointSeriesDescription(); });
        a.z("PointSeries", PointSeriesDescriptionMetadata.a);
    };
    PointSeriesDescriptionMetadata.$t = markType(PointSeriesDescriptionMetadata, 'PointSeriesDescriptionMetadata');
    PointSeriesDescriptionMetadata.a = null;
    return PointSeriesDescriptionMetadata;
}(Base));
export { PointSeriesDescriptionMetadata };
